bootstrap_yahoofinance_registry: Bootstrap Yahoo Finance Runtime Registry

bootstrap_yahoofinance_registryR Documentation

Bootstrap Yahoo Finance Runtime Registry

Description

Create an absent runtime registry from the tracked package seed. Existing registries are never overwritten; they are validated and an actionable error is raised if required fallback declarations have drifted.

Usage

bootstrap_yahoofinance_registry(
  registry_path = get_yahoofinance_registry_file_path(),
  seed_path = get_yahoofinance_seed_registry_path()
)

Arguments

registry_path

Runtime registry JSON path.

seed_path

Package seed registry JSON path.

Value

Invisibly returns the runtime registry path.


investdatar documentation built on Aug. 21, 2026, 5:17 p.m.