describe_fred_data: Describe FRED Data

View source: R/data_narrative.R

describe_fred_dataR Documentation

Describe FRED Data

Description

Creates a compact narrative describing the structure and meaning of a locally stored FRED series for downstream analyst agents.

Usage

describe_fred_data(
  series_id,
  local_path = NULL,
  registry_path = get_fred_registry_file_path()
)

Arguments

series_id

FRED series identifier.

local_path

Optional local storage path used to read the local series.

registry_path

Optional registry path used to resolve series metadata.

Value

Character scalar narrative.


investdatar documentation built on Aug. 21, 2026, 5:17 p.m.