describe_quantmod_data: Describe quantmod Data

View source: R/data_narrative.R

describe_quantmod_dataR Documentation

Describe quantmod Data

Description

Fetches market OHLCV data through quantmod and creates a compact narrative for the resulting standardized market table.

Usage

describe_quantmod_data(
  ticker,
  label = ticker,
  from = NULL,
  to = NULL,
  src = "yahoo",
  local_path = NULL
)

Arguments

ticker

Market symbol passed to quantmod::getSymbols().

label

Optional label to store in the standardized symbol column.

from

Start date. If NULL, use the oldest date in local quantmod data for label.

to

End date. If NULL, use the newest date in local quantmod data for label.

src

quantmod source, default "yahoo".

local_path

Optional local storage path used when from or to is omitted.

Value

Character scalar narrative.


investdatar documentation built on Aug. 21, 2026, 5:17 p.m.