| is_sync_run_successful | R Documentation |
A run is successful when its stored summary contains no row with an error status or non-empty error message. Empty summaries are successful because an intentionally empty registry has no failed work.
is_sync_run_successful(run)
run |
A run-log object returned by |
Logical scalar.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.