repair_local_okx_candle_gaps: Repair Local OKX Candle Data From Multiple History Pages

View source: R/okx_candle_data.R

repair_local_okx_candle_gapsR Documentation

Repair Local OKX Candle Data From Multiple History Pages

Description

Fetches multiple OKX historical candle pages in memory and writes the merged repair result to local storage with one sync_local_data() call.

Usage

repair_local_okx_candle_gaps(
  inst_id,
  bar,
  before,
  config = NULL,
  local_path = NULL,
  limit = 100L,
  tz = "UTC",
  storage = c("single", "monthly")
)

Arguments

inst_id

Instrument identifier.

bar

Candle interval.

before

Character/numeric vector of OKX history pagination cursors.

config

Optional OKX API config. If omitted, defaults from the package config and OKX_API_KEY / OKX_SECRET_KEY / OKX_PASSPHRASE environment variables are used.

local_path

Optional OKX storage path.

limit

Integer page size.

tz

Output time zone.

storage

Local storage mode: monolithic "single" or monthly partitioned "monthly".

Value

A sync result list.


investdatar documentation built on Aug. 21, 2026, 5:17 p.m.