| bootstrap_yahoofinance_registry | R Documentation |
Create an absent runtime registry from the tracked package seed. Existing registries are never overwritten; they are validated and an actionable error is raised if required fallback declarations have drifted.
bootstrap_yahoofinance_registry(
registry_path = get_yahoofinance_registry_file_path(),
seed_path = get_yahoofinance_seed_registry_path()
)
registry_path |
Runtime registry JSON path. |
seed_path |
Package seed registry JSON path. |
Invisibly returns the runtime registry path.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.