View source: R/data_narrative.R
| describe_fred_data | R Documentation |
Creates a compact narrative describing the structure and meaning of a locally stored FRED series for downstream analyst agents.
describe_fred_data(
series_id,
local_path = NULL,
registry_path = get_fred_registry_file_path()
)
series_id |
FRED series identifier. |
local_path |
Optional local storage path used to read the local series. |
registry_path |
Optional registry path used to resolve series metadata. |
Character scalar narrative.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.