| get_investdatar_config | R Documentation |
Returns the cached package configuration, loading it from YAML if needed.
get_investdatar_config(
reload = FALSE,
config_path = Sys.getenv("INVESTDATAR_CONFIG", unset = "")
)
reload |
Logical. Reload from disk even if configuration is already cached. |
config_path |
Optional config path used when |
A configuration list.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.