| sync_local_data | R Documentation |
Merges freshly retrieved source data into a local .rds file and stores a
sidecar metadata file containing the local update time and source update time.
sync_local_data(
new_data,
local_file_path,
key_cols,
order_cols = key_cols,
source_utime = NULL,
local_updated_at = Sys.time()
)
new_data |
A |
local_file_path |
Output |
key_cols |
Character vector of key columns used for de-duplication. |
order_cols |
Character vector used to sort the merged data. |
source_utime |
Optional upstream update time recorded in metadata. |
local_updated_at |
Optional local update time override. |
A list describing the sync result.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.